@@ -1,5 +1,5 @@
 """Flow engine."""
 
 from .executor import Executor  # noqa: F401
-from .flow import Flow, FlowStatus  # noqa: F401
+from .flow import Flow, FlowExecError, FlowStatus, get_outer_function  # noqa: F401
 from .step import Prop, Step  # noqa: F401
