@@ -17,11 +17,7 @@ class Step:
     """A Step of the flow."""
 
     forward_call: Callable[[List[Prop]], List[Prop]]
-    forward_in: List[str]
-    forward_out: List[str]
     backward_call: Callable[[List[Prop]], List[Prop]]
-    backward_in: List[str]
-    backward_out: List[str]
 
 
 def dummy_backward(prop: List[Prop]) -> Prop:
